{#def person, search_link, searchFacet, roles = None #}
{% set person_dict = person | to_dict %}
{% set title = person_dict.fullName ~ ": " ~ _("Find more records by this person") %}
{% set data = {
    "value": person_dict.fullName,
    "title": title,
    "label": person_dict.fullName
} %}
<div role="listitem" class="item creatibutor-wrap separated">
        <div class="content">
            <SearchLink data={data} className="search-link" searchFacet={searchFacet} search_link={search_link}></SearchLink>
            {%- if roles -%}
                ({{roles | map(attribute='title') | join(', ') }})
            {%- endif -%}
        </div>
    </div>
